==> haskell-pattern-arrows-0.0.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pattern-arrows
version:              0.0.2
visibility:           public
id:                   pattern-arrows-0.0.2-9zo3bRa7ilQ8Nh412YK46x
key:                  pattern-arrows-0.0.2-9zo3bRa7ilQ8Nh412YK46x
license:              MIT
copyright:            (c) Phil Freeman 2013
maintainer:           Phil Freeman <paf31@cantab.net>
author:               Phil Freeman <paf31@cantab.net>
stability:            experimental
homepage:
    http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html

synopsis:             Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.

category:             Text, Combinators, Pretty Printer
abi:                  2127714f8b5d41750c61b06e7f52068a
exposed:              True
exposed-modules:      Control.PatternArrows
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pattern-arrows-0.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/pattern-arrows-0.0.2
hs-libraries:         HSpattern-arrows-0.0.2-9zo3bRa7ilQ8Nh412YK46x
depends:              base-4.15.1.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock

haddock-html:         /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pattern-arrows-0.0.2-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pattern-arrows
version:              0.0.2
visibility:           public
id:                   pattern-arrows-0.0.2-GSdW4T8e4tq1BsnRufVwWM
key:                  pattern-arrows-0.0.2-GSdW4T8e4tq1BsnRufVwWM
license:              MIT
copyright:            (c) Phil Freeman 2013
maintainer:           Phil Freeman <paf31@cantab.net>
author:               Phil Freeman <paf31@cantab.net>
stability:            experimental
homepage:
    http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html

synopsis:             Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.

category:             Text, Combinators, Pretty Printer
abi:                  ff724a8fbc07a855400189b257caabf5
exposed:              True
exposed-modules:      Control.PatternArrows
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pattern-arrows-0.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pattern-arrows
hs-libraries:         HSpattern-arrows-0.0.2-GSdW4T8e4tq1BsnRufVwWM
depends:              base-4.16.4.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock

haddock-html:         /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
